
%% Computing the characteristic value of operator -1/2 + K_D^omega for a disk

% Unperturbed characteristic value : 1.8412 = the first zero of J_1'(z)



clear all;
close all;
clc;


%%%%%%%%%%%% 1st method : Using Muller's method %%%%%%%%%%%%%%

r = 1; % radius of a disk
nbPoints = 100; %number of points on the boundary
theta = 2*pi*(0:nbPoints-1)/nbPoints;
D=ellipse(r,r,0,0,nbPoints);


%%% eps*h represents a small perturbation of the boundary
eps = 0.01; 
h = cos(2*theta);
dh = -2*sin(2*theta);
tau = sqrt( D.avec(1,:).^2 + D.avec(2,:).^2 );

%%% make the perturbed boundary
points_eps = [ (r + eps*h) .* cos(theta) ; (r + eps*h) .* sin(theta) ];
D_eps = splineCurve(points_eps);

%%% define a function which computes the smallest eigenvalue of the
%%% operator 'A'
f = @(z) eigs((-1/2)*eye(D.nbPoints) + KD_Helm(z,D),1,'sm');
f_eps = @(z) eigs((-1/2)*eye(D_eps.nbPoints) + KD_Helm(z,D_eps),1,'sm');


%%% compute the characteristic value of 'A' by applying muller's method
z0 = 1.9;
z1 = 1.87;
z2 = 1.85;
distTol = 5e-12; fTol = 1e-12; iterMax = 500;
[char_eps1, fRoot, iterN] = MullersMethod(f_eps, z0, z1, z2, iterMax, distTol, fTol);

z0 = 1.6;
z1 = 1.7;
z2 = 1.8;
distTol = 5e-12; fTol = 1e-12; iterMax = 500;
[char_eps2, fRoot, iterN] = MullersMethod(f_eps, z0, z1, z2, iterMax, distTol, fTol);




%%%%%%%%%%%% 2nd method : Using Shape derivative %%%%%%%%%%%%%%

w0 = 1.8412;
rV0 = 0.5; % radius of nbhd V0
nbPointsV0 = 100; % number of points on the boundary of V0

%%% compute a_1(eps) and a_2(eps)
[a1 a2] = al_asymp(D,w0,rV0,h,dh,tau,nbPoints,nbPointsV0,eps);

%%% compute the perturbation of char. value from a_1(eps) and a_2(eps)
diff1 = 1/2*(a1 + sqrt(2*a2-(a1)^2));
diff2 = 1/2*(a1 - sqrt(2*a2-(a1)^2));

%%% compute approximation of splitted char. values
char_sd1 = w0 + diff1 ;
char_sd2 = w0 + diff2 ;


%%% print output
fprintf('       Unperturbed char. value');
[w0*1]

fprintf('       Numerical    | Use Shape derivative');
[ char_eps1 char_sd1 ; char_eps2 char_sd2]